@@ -1,5 +1,4 @@
-
-/* $Id: gamma.c,v 1.1.1.1 1999/08/19 00:55:40 jtg Exp $ */
+/* $Id: gamma.c,v 1.3 2002/04/22 16:03:37 brianp Exp $ */
 
 /* Draw test patterns to help determine correct gamma value for a display.
    When the intensities of the inner squares nearly match the intensities
@@ -23,19 +22,6 @@
 
 /* Conversion to GLUT by Mark J. Kilgard */
 
-/*
- * $Log: gamma.c,v $
- * Revision 1.1.1.1  1999/08/19 00:55:40  jtg
- * Imported sources
- *
- * Revision 3.1  1999/06/19 01:35:38  brianp
- * merged in Kai Schuetz's RGB changes
- *
- * Revision 3.0  1998/02/14 18:42:29  brianp
- * initial rev
- *
- */
-
 
 #include <stdio.h>
 #include <string.h>
@@ -130,8 +116,9 @@ gamma_ramp(GLfloat yoffs, GLfloat r, GLfloat g, GLfloat b)
 
   for(d = 1; d < 4; d++) {  /* increasing density from 25% to 75% */
     GLfloat xcoord = (-1.0 + d*0.4);
+    GLfloat t = d * 0.25;
 
-    glColor3f(r*d / 5.0, g*d / 5.0, b*d / 5.0); /* draw outer rect */
+    glColor3f(r*t, g*t, b*t); /* draw outer rect */
     glRectf(xcoord, yoffs, xcoord+0.4, yoffs + 0.5);
 
     glColor3f(0.0, 0.0, 0.0);   /* "clear" inner rect */
