@@ -1,4 +1,4 @@
-/* $Id: reflect.c,v 1.3 2000/06/15 14:25:48 brianp Exp $ */
+/* $Id: reflect.c,v 1.7 2001/04/25 15:51:32 brianp Exp $ */
 
 /*
  * Demo of a reflective, texture-mapped surface with OpenGL.
@@ -53,7 +53,11 @@ static GLfloat spin;
 
 static GLint Width = 400, Height = 300;
 static GLenum ShowBuffer = GL_NONE;
+static GLboolean Anim = GL_TRUE;
 
+/* performance info */
+static GLint T0 = 0;
+static GLint Frames = 0;
 
 
 static void make_table( void )
@@ -144,7 +148,7 @@ static void init( void )
    glEnable( GL_LIGHT0 );
    glEnable( GL_LIGHTING );
 
-   glClearColor( 0.5, 0.5, 0.9, 1.0 );
+   glClearColor( 0.5, 0.5, 0.9, 0.0 );
 
    glEnable( GL_NORMALIZE );
 }
@@ -293,8 +297,31 @@ static void draw_scene( void )
    else if (ShowBuffer == GL_STENCIL) {
       ShowStencilBuffer(Width, Height, 255.0, 0.0);
    }
+   else if (ShowBuffer == GL_ALPHA) {
+      ShowAlphaBuffer(Width, Height);
+   }
 
    glutSwapBuffers();
+
+   {
+      GLint t = glutGet(GLUT_ELAPSED_TIME);
+      Frames++;
+      if (t - T0 >= 5000) {
+         GLfloat seconds = (t - T0) / 1000.0;
+         GLfloat fps = Frames / seconds;
+         printf("%d frames in %g seconds = %g FPS\n", Frames, seconds, fps);
+         T0 = t;
+         Frames = 0;
+      }
+   }
+}
+
+
+static void idle( void )
+{
+   spin += 2.0;
+   yrot += 3.0;
+   glutPostRedisplay();
 }
 
 
@@ -308,6 +335,16 @@ static void Key( unsigned char key, int x, int y )
    else if (key == 's') {
       ShowBuffer = GL_STENCIL;
    }
+   else if (key == 'a') {
+      ShowBuffer = GL_ALPHA;
+   }
+   else if (key == ' ') {
+      Anim = !Anim;
+      if (Anim)
+         glutIdleFunc(idle);
+      else
+         glutIdleFunc(NULL);
+   }
    else if (key==27) {
       exit(0);
    }
@@ -344,16 +381,6 @@ static void SpecialKey( int key, int x, int y )
 }
 
 
-
-static void idle( void )
-{
-   spin += 2.0;
-   yrot += 3.0;
-   glutPostRedisplay();
-}
-
-
-
 int main( int argc, char *argv[] )
 {
    glutInit(&argc, argv);
