@@ -1,37 +1,10 @@
-/* $Id: trispd.c,v 1.2 2000/10/26 15:26:14 brianp Exp $ */
+/* $Id: trispd.c,v 1.4 2002/07/12 15:54:02 brianp Exp $ */
 
 /*
  * Simple GLUT program to measure triangle strip rendering speed.
  * Brian Paul  February 15, 1997  This file is in the public domain.
  */
 
-/*
- * $Log: trispd.c,v $
- * Revision 1.2  2000/10/26 15:26:14  brianp
- * added a glFinish() call
- *
- * Revision 1.1.1.1  1999/08/19 00:55:40  jtg
- * Imported sources
- *
- * Revision 3.4  1999/03/28 18:24:37  brianp
- * minor clean-up
- *
- * Revision 3.3  1999/03/18 08:16:52  joukj
- *
- *     cmpstr needs string.h to included to avoid warnings
- *
- * Revision 3.2  1998/07/08 03:02:00  brianp
- * added Marten Stromberg's texture options
- *
- * Revision 3.1  1998/06/29 02:36:58  brianp
- * removed unneeded includes
- *
- * Revision 3.0  1998/02/14 18:42:29  brianp
- * initial rev
- *
- */
-
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <math.h>
@@ -158,7 +131,7 @@ static void LoadTex(int comp, int filter)
 {
    GLubyte *pixels;
    int x, y;
-   pixels = malloc(4*256*256);
+   pixels = (GLubyte *) malloc(4*256*256);
    for (y = 0; y < 256; ++y)
       for (x = 0; x < 256; ++x) {
 	 pixels[(y*256+x)*4+0] = (int)(128.5 + 127.0 * cos(0.024544 * x));
